"""Implementation of the classroommode command."""

from mcipc.rcon.client import Client


__all__ = ['classroommode']


def classroommode(self: Client):
    """Unknown invocation and behaviour.
    See: https://minecraft.gamepedia.com/Commands/classroommode
    """

    raise NotImplementedError(__doc__)
